summaryrefslogtreecommitdiffstats
path: root/kregexpeditor/textwidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:52 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:52 -0600
commit7ea89afa119615e547323a7a482ea7fef8e67029 (patch)
tree7b28540e70b4be9a779347f70486d4937258a875 /kregexpeditor/textwidget.cpp
parentbcc684e28ad6f9ebeeae5d334a4dc297cef3e816 (diff)
downloadtdeutils-7ea89afa119615e547323a7a482ea7fef8e67029.tar.gz
tdeutils-7ea89afa119615e547323a7a482ea7fef8e67029.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kregexpeditor/textwidget.cpp')
-rw-r--r--kregexpeditor/textwidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kregexpeditor/textwidget.cpp b/kregexpeditor/textwidget.cpp
index 9c58e66..5de0dee 100644
--- a/kregexpeditor/textwidget.cpp
+++ b/kregexpeditor/textwidget.cpp
@@ -56,13 +56,13 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
// I need to force the parent to tqrepaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
// case the parent would not tqrepaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());
if (p)
- p->tqrepaint();
+ p->repaint();
_editorWindow->updateContent( this );
}
@@ -56,13 +56,13 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
- // I need to force the parent to tqrepaint, as the size change of this
+ // I need to force the parent to repaint, as the size change of this
// widget may not be enough for the parent to change size, and in that
@@ -56,13 +56,13 @@ void TextWidget::init( const TQString& txt )
// widget may not be enough for the parent to change size, and in that
- // case the parent would not tqrepaint, and the text widget would not be
+ // case the parent would not repaint, and the text widget would not be
// resized.
TQWidget *p = TQT_TQWIDGET(parent());